==> lying-cli-1.0.0.tgz: package/src/create.js <==
const axios = require('axios')
const ora = require('ora') // 等待
const inquirer = require('inquirer')
const {
    GithubApi,
    downloadDir
} = require('./constants')
const { promisify } = require('util')
const path = require('path')
let downloadGitRepo = require('download-git-repo')
downloadGitRepo = promisify(downloadGitRepo)
let ncp = require('ncp')
ncp = promisify(ncp)
// 获取仓库模板信息
const repostryList = async () => {
    const {data} = await axios.get(`${GithubApi}/users/HC74/repos`)
    return data
}
// 获取仓库tag
const getTags = async (repostry) => {
    const {
        data
    } = await axios.get(`${GithubApi}/repos/HC74/${repostry}/tags`)
    return data
}

// 下载项目
const download = async (repstry,tag) => {
    let api = `HC74/${repstry}`
    if (tag){
        api += `#${tag}`
    }
    const dest = `${downloadDir}/${repstry}`
    await downloadGitRepo(api,dest)
    return dest
}

// 封装loding方法
const waitLoding = (func,message) => async (...args) => {
    const spinner = ora(message)
    spinner.start()
    const repostrys = await func(...args)
    spinner.succeed()
    return repostrys
}

module.exports = async proname => {
    let repostrys = await  waitLoding(repostryList,"Initialize project...")()
    repostrys = repostrys.map(item => {
        if (item.name.indexOf("lying-cli") !== -1){
            return item.name
        }
    }).filter(e => e !== undefined)
    const {
        repostry
    } = await inquirer.prompt({
        name: "repostry", //选择后的结果
        type: 'list', //以什么方式展示
        message: 'please select the project type (请选择项目的类型)',
        choices: repostrys
    })
    console.log("repstory",repostry)
    // 获取版本号 tag
    let tags = await waitLoding(getTags,'get taging ...')(repostry)
    tags = tags.map(item => item.name)
    // 选择版本
    const {
        tag
    } = await inquirer.prompt({
        name: 'tag',
        type: 'list',
        message: "please select the project tag (请选择项目的版本)",
        choices: tags
    })

    // 下载项目 返回一个临时存放目录
    const result = await waitLoding(download,'build project..')(repostry,tag)
    await ncp(result,path.resolve(proname))
}

==> lying-cli-1.0.1.tgz: package/src/create.js <==
const axios = require('axios')
const ora = require('ora') // 等待
const inquirer = require('inquirer')
const {
    GithubApi,
    downloadDir,
    getType
} = require('./constants')
const { promisify } = require('util')
const path = require('path')
let downloadGitRepo = require('download-git-repo')
downloadGitRepo = promisify(downloadGitRepo)
let ncp = require('ncp')
ncp = promisify(ncp)
// 获取仓库模板信息
const repostryList = async () => {
    const {data} = await axios.get(`${GithubApi}/users/HC74/repos`)
    return data
}
// 获取仓库tag
const getTags = async (repostry) => {
    const {
        data
    } = await axios.get(`${GithubApi}/repos/HC74/${repostry}/tags`)
    return data
}

// 下载项目
const download = async (repstry,tag) => {
    let api = `HC74/${repstry}`
    if (tag){
        api += `#${tag}`
    }
    const dest = `${downloadDir}/${repstry}`
    await downloadGitRepo(api,dest)
    return dest
}

// 封装loding方法
const waitLoding = (func,message) => async (...args) => {
    const spinner = ora(message)
    spinner.start()
    const repostrys = await func(...args)
    spinner.succeed()
    return repostrys
}

module.exports = async proname => {
    let repostrys = await  waitLoding(repostryList,"Initialize project...")()
    repostrys = repostrys.map(item => {
        if (item.name.indexOf("lying-cli") === -1){
            return undefined
        }
        if (item.name === "lying-cli-template-init"){
            return "*Default(Vue3+uView+Uni-UI+Vite)"
        }
    }).filter(e => e !== undefined)
    let {
        repostry
    } = await inquirer.prompt({
        name: "repostry", //选择后的结果
        type: 'list', //以什么方式展示
        message: 'please select the project type (请选择项目的类型)',
        choices: repostrys
    })
    repostry = getType(repostry)
    // 获取版本号 tag
    let tags = await waitLoding(getTags,'get taging ...')(repostry)
    tags = tags.map(item => item.name)
    // 选择版本
    const {
        tag
    } = await inquirer.prompt({
        name: 'tag',
        type: 'list',
        message: "please select the project tag (请选择项目的版本)",
        choices: tags
    })

    // 下载项目 返回一个临时存放目录
    const result = await waitLoding(download,'build project..')(repostry,tag)
    await ncp(result,path.resolve(proname))
}
